@@ -29,13 +29,11 @@
 -- Copyright 2009-2010 Corey O'Connor
 module Graphics.Vty.Inline
   ( module Graphics.Vty.Inline
-  , withVty
   )
 where
 
 import Graphics.Vty
 import Graphics.Vty.DisplayAttributes
-import Graphics.Vty.Inline.Unsafe
 
 import Blaze.ByteString.Builder (writeToByteString)
 
@@ -56,13 +54,13 @@ data InlineState =
 -- | Set the background color to the provided 'Color'.
 backColor :: Color -> InlineM ()
 backColor c = modify $ \s ->
-    s { inlineAttr = inlineAttr s `mappend` (currentAttr `withBackColor` c)
+    s { inlineAttr = inlineAttr s `withBackColor` c
       }
 
 -- | Set the foreground color to the provided 'Color'.
 foreColor :: Color -> InlineM ()
 foreColor c = modify $ \s ->
-    s { inlineAttr = inlineAttr s `mappend` (currentAttr `withForeColor` c)
+    s { inlineAttr = inlineAttr s `withForeColor` c
       }
 
 -- | Attempt to change the 'Style' of the following text..
@@ -71,7 +69,7 @@ foreColor c = modify $ \s ->
 -- produced. The style can still be removed.
 applyStyle :: Style -> InlineM ()
 applyStyle st = modify $ \s ->
-    s { inlineAttr = inlineAttr s `mappend` (currentAttr `withStyle` st)
+    s { inlineAttr = inlineAttr s `withStyle` st
       }
 
 -- | Attempt to remove the specified 'Style' from the display of the
@@ -119,8 +117,8 @@ putAttrChange out c = liftIO $ do
 -- output device.
 --
 -- This will flush the terminal output.
-putAttrChange_ :: ( Applicative m, MonadIO m ) => InlineM () -> m ()
-putAttrChange_ c = liftIO $ withOutput $ \out -> do
+putAttrChange_ :: ( Applicative m, MonadIO m ) => Output -> InlineM () -> m ()
+putAttrChange_ out c = liftIO $ do
     hFlush stdout
     putAttrChange out c
     hFlush stdout
